@@ -1,18 +1,17 @@
 import discord
 from discord.ext import commands
-from Daug.functions import excepter
-from Daug.functions.embeds import compose_embed_from_message
-
+from Daug.utils import excepter
+from Daug.utils.embeds import compose_embed_from_message
 
 class Favorite(commands.Cog):
-    """お気に入り機能"""
-    def __init__(self, bot):
+    """お気に入り掲載"""
+    def __init__(self, bot, guild_id, channel_id):
         self.bot = bot
-        self.id = self.bot.config['Daug']['guild_id']
-        self.channel_tips_id = self.bot.config['Daug']['channel_tips_id']
+        self.guild_id = guild_id
+        self.channel_id = channel_id
 
     async def dispatch_tips(self, message):
-        channel = self.bot.get_channel(self.channel_tips_id)
+        channel = self.bot.get_channel(self.channel_id)
         await channel.send(embed=compose_embed_from_message(message))
 
     @commands.Cog.listener()
@@ -22,7 +21,7 @@ class Favorite(commands.Cog):
         if not isinstance(channel, discord.channel.TextChannel):
             return
         author = channel.guild.get_member(payload.user_id)
-        if payload.guild_id != self.id:
+        if payload.guild_id != self.guild_id:
             return
         if author.bot:
             return
